@@ -17,7 +17,9 @@
 #
 # Refer to the README and COPYING files for full details of the license
 #
+
 from __future__ import absolute_import
+from __future__ import division
 
 """
 This module contains functions to preprocess the domain XML before submitting
@@ -91,6 +93,7 @@ from vdsm import osinfo
 
 from vdsm.common import cpuarch
 from vdsm.common import hooks
+from vdsm.common import xmlutils
 from vdsm.virt import domain_descriptor
 from vdsm.virt import libvirtxml
 from vdsm.virt import metadata
@@ -135,7 +138,7 @@ def update_leases_xml_from_disk_objs(vm, dom, disk_devices):
         params = vmdevices.lease.parse_xml(dev_elem, {})
         if not params:
             vm.log.warning('could not parse lease: %s',
-                           vmxml.format_xml(dev_elem))
+                           xmlutils.tostring(dev_elem))
             continue
 
         info = vmdevices.lease.find_drive_lease_info(
@@ -183,7 +186,7 @@ def update_disks_xml_from_objs(vm, dom, disk_devices):
         attrs = vmdevices.storage.Drive.get_identifying_attrs(dev_elem)
         if not attrs:
             vm.log.warning('could not identify drive: %s',
-                           vmxml.format_xml(dev_elem))
+                           xmlutils.tostring(dev_elem))
             continue
 
         try:
@@ -235,12 +238,12 @@ def replace_device_xml_with_hooks_xml(dom, vm_id, vm_custom, md_desc=None):
             continue
 
         hook_xml = hooks.before_device_create(
-            vmxml.format_xml(dev_elem, pretty=True),
+            xmlutils.tostring(dev_elem, pretty=True),
             vm_custom,
             dev_custom)
 
         to_remove.append(dev_elem)
-        to_append.append(vmxml.parse_xml(hook_xml))
+        to_append.append(xmlutils.fromstring(hook_xml))
 
     for dev_elem in to_remove:
         vmxml.remove_child(devs, dev_elem)
