@@ -18,9 +18,10 @@
 # Refer to the README and COPYING files for full details of the license
 #
 
+from __future__ import absolute_import
+from __future__ import division
 from __future__ import print_function
 
-
 from vdsm.storage import devicemapper
 from vdsm.storage import mpathhealth
 from vdsm.storage import udev
